@@ -11,14 +11,19 @@ const CcAddresses = JSON.parse(core.getInput('ccAddresses'));
 const ToAddresses = JSON.parse(core.getInput('toAddresses'));
 const ReplyToAddresses = JSON.parse(core.getInput('replyToAddresses'));
 const workflowURL = core.getInput('workflowURL');
+const subject = core.getInput('subject');
+const bodyPath = core.getInput('bodyPath');
 
 const data = dataFilePath ? fs.readFileSync(dataFilePath, { encoding: 'utf-8' }) : "";
+const body = bodyPath ? fs.readFileSync(bodyPath, { encoding: 'utf-8' }) : "";
 
 const templated = {
     version,
     format,
     results: data,
     workflowURL,
+    subject,
+    body,
 };
 
 // Set the region
