@@ -21,7 +21,7 @@ import (
 	"github.com/dolthub/dolt/go/store/datas/pull"
 )
 
-func pullerProgFunc(ctx context.Context, pullerEventCh <-chan pull.PullerEvent) {
+func pullerProgFunc(ctx context.Context, statsCh <-chan pull.Stats) {
 	for {
 		select {
 		case <-ctx.Done():
@@ -31,7 +31,7 @@ func pullerProgFunc(ctx context.Context, pullerEventCh <-chan pull.PullerEvent)
 		select {
 		case <-ctx.Done():
 			return
-		case <-pullerEventCh:
+		case <-statsCh:
 		default:
 		}
 	}
@@ -53,8 +53,8 @@ func progFunc(ctx context.Context, progChan <-chan pull.PullProgress) {
 	}
 }
 
-func NoopRunProgFuncs(ctx context.Context) (*sync.WaitGroup, chan pull.PullProgress, chan pull.PullerEvent) {
-	pullerEventCh := make(chan pull.PullerEvent)
+func NoopRunProgFuncs(ctx context.Context) (*sync.WaitGroup, chan pull.PullProgress, chan pull.Stats) {
+	statsCh := make(chan pull.Stats)
 	progChan := make(chan pull.PullProgress)
 	wg := &sync.WaitGroup{}
 
@@ -67,15 +67,15 @@ func NoopRunProgFuncs(ctx context.Context) (*sync.WaitGroup, chan pull.PullProgr
 	wg.Add(1)
 	go func() {
 		defer wg.Done()
-		pullerProgFunc(ctx, pullerEventCh)
+		pullerProgFunc(ctx, statsCh)
 	}()
 
-	return wg, progChan, pullerEventCh
+	return wg, progChan, statsCh
 }
 
-func NoopStopProgFuncs(cancel context.CancelFunc, wg *sync.WaitGroup, progChan chan pull.PullProgress, pullerEventCh chan pull.PullerEvent) {
+func NoopStopProgFuncs(cancel context.CancelFunc, wg *sync.WaitGroup, progChan chan pull.PullProgress, statsCh chan pull.Stats) {
 	cancel()
 	close(progChan)
-	close(pullerEventCh)
+	close(statsCh)
 	wg.Wait()
 }
