@@ -337,7 +337,7 @@ func TestDecimalMarshal(t *testing.T) {
 			"16976349273982359874209023948672021737840592720387475.271912873754", false},
 		{65, 12, "99999999999999999999999999999999999999999999999999999.9999999999999", "", true},
 
-		{20, 10, []byte{32}, "32", false},
+		{20, 10, []byte{32}, "", true},
 		{20, 10, time.Date(2019, 12, 12, 12, 12, 12, 0, time.UTC), "", true},
 	}
 
