@@ -87,7 +87,7 @@ func TestRenameTable(t *testing.T) {
 			require.NoError(t, err)
 
 			// setup tests
-			root, err = ExecuteSql(t, dEnv, root, setup)
+			root, err = ExecuteSql(dEnv, root, setup)
 			require.NoError(t, err)
 
 			schemas, err := root.GetAllSchemas(ctx)
@@ -121,6 +121,8 @@ func TestRenameTable(t *testing.T) {
 const tableName = "people"
 
 func TestAddColumnToTable(t *testing.T) {
+	origRows, sch, err := dtestutils.RowsAndSchema()
+	require.NoError(t, err)
 
 	tests := []struct {
 		name           string
@@ -140,9 +142,9 @@ func TestAddColumnToTable(t *testing.T) {
 			newColName: "newCol",
 			colKind:    types.IntKind,
 			nullable:   Null,
-			expectedSchema: dtestutils.AddColumnToSchema(dtestutils.TypedSchema,
+			expectedSchema: dtestutils.AddColumnToSchema(sch,
 				schema.NewColumn("newCol", dtestutils.NextTag, types.IntKind, false)),
-			expectedRows: dtestutils.TypedRows,
+			expectedRows: origRows,
 		},
 		{
 			name:       "nullable with nil default",
@@ -150,9 +152,9 @@ func TestAddColumnToTable(t *testing.T) {
 			newColName: "newCol",
 			colKind:    types.IntKind,
 			nullable:   Null,
-			expectedSchema: dtestutils.AddColumnToSchema(dtestutils.TypedSchema,
+			expectedSchema: dtestutils.AddColumnToSchema(sch,
 				schemaNewColumnWithDefault("newCol", dtestutils.NextTag, types.IntKind, false, "")),
-			expectedRows: dtestutils.TypedRows,
+			expectedRows: origRows,
 		},
 		{
 			name:       "nullable with non-nil default",
@@ -161,9 +163,9 @@ func TestAddColumnToTable(t *testing.T) {
 			colKind:    types.IntKind,
 			nullable:   Null,
 			defaultVal: mustStringToColumnDefault("42"),
-			expectedSchema: dtestutils.AddColumnToSchema(dtestutils.TypedSchema,
+			expectedSchema: dtestutils.AddColumnToSchema(sch,
 				schemaNewColumnWithDefault("newCol", dtestutils.NextTag, types.IntKind, false, "42")),
-			expectedRows: dtestutils.AddColToRows(t, dtestutils.TypedRows, dtestutils.NextTag, types.NullValue),
+			expectedRows: addColToRows(t, origRows, dtestutils.NextTag, types.NullValue),
 		},
 		{
 			name:       "first order",
@@ -181,7 +183,7 @@ func TestAddColumnToTable(t *testing.T) {
 				schema.NewColumn("is_married", dtestutils.IsMarriedTag, types.IntKind, false, schema.NotNullConstraint{}),
 				schema.NewColumn("title", dtestutils.TitleTag, types.StringKind, false),
 			),
-			expectedRows: dtestutils.AddColToRows(t, dtestutils.TypedRows, dtestutils.NextTag, types.NullValue),
+			expectedRows: addColToRows(t, origRows, dtestutils.NextTag, types.NullValue),
 		},
 		{
 			name:       "middle order",
@@ -199,7 +201,7 @@ func TestAddColumnToTable(t *testing.T) {
 				schema.NewColumn("is_married", dtestutils.IsMarriedTag, types.IntKind, false, schema.NotNullConstraint{}),
 				schema.NewColumn("title", dtestutils.TitleTag, types.StringKind, false),
 			),
-			expectedRows: dtestutils.AddColToRows(t, dtestutils.TypedRows, dtestutils.NextTag, types.NullValue),
+			expectedRows: addColToRows(t, origRows, dtestutils.NextTag, types.NullValue),
 		},
 		{
 			name:        "tag collision",
@@ -255,19 +257,24 @@ func TestAddColumnToTable(t *testing.T) {
 }
 
 func makePeopleTable(ctx context.Context, dEnv *env.DoltEnv) (*env.DoltEnv, error) {
+	_, sch, err := dtestutils.RowsAndSchema()
+	if err != nil {
+		return nil, err
+	}
+
 	root, err := dEnv.WorkingRoot(ctx)
 	if err != nil {
 		return nil, err
 	}
-	rows, err := durable.NewEmptyIndex(ctx, root.VRW(), root.NodeStore(), dtestutils.TypedSchema)
+	rows, err := durable.NewEmptyIndex(ctx, root.VRW(), root.NodeStore(), sch)
 	if err != nil {
 		return nil, err
 	}
-	indexes, err := durable.NewIndexSetWithEmptyIndexes(ctx, root.VRW(), root.NodeStore(), dtestutils.TypedSchema)
+	indexes, err := durable.NewIndexSetWithEmptyIndexes(ctx, root.VRW(), root.NodeStore(), sch)
 	if err != nil {
 		return nil, err
 	}
-	tbl, err := doltdb.NewTable(ctx, root.VRW(), root.NodeStore(), dtestutils.TypedSchema, rows, indexes, nil)
+	tbl, err := doltdb.NewTable(ctx, root.VRW(), root.NodeStore(), sch, rows, indexes, nil)
 	if err != nil {
 		return nil, err
 	}
@@ -295,133 +302,6 @@ func schemaNewColumnWithDefault(name string, tag uint64, kind types.NomsKind, pa
 	return col
 }
 
-func TestDropColumn(t *testing.T) {
-	tests := []struct {
-		name           string
-		colName        string
-		expectedSchema schema.Schema
-		expectedErr    string
-	}{
-		{
-			name:           "remove int",
-			colName:        "age",
-			expectedSchema: dtestutils.RemoveColumnFromSchema(dtestutils.TypedSchema, dtestutils.AgeTag),
-		},
-		{
-			name:           "remove string",
-			colName:        "title",
-			expectedSchema: dtestutils.RemoveColumnFromSchema(dtestutils.TypedSchema, dtestutils.TitleTag),
-		},
-		{
-			name:        "column not found",
-			colName:     "not found",
-			expectedErr: "column not found",
-		},
-		{
-			name:        "remove primary key col",
-			colName:     "id",
-			expectedErr: "Cannot drop column in primary key",
-		},
-	}
-
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			ctx := context.Background()
-			dEnv, err := makePeopleTable(ctx, dtestutils.CreateTestEnv())
-			require.NoError(t, err)
-
-			root, err := dEnv.WorkingRoot(ctx)
-			require.NoError(t, err)
-			tbl, _, err := root.GetTable(ctx, tableName)
-			require.NoError(t, err)
-
-			updatedTable, err := dropColumn(ctx, tbl, tt.colName)
-			if len(tt.expectedErr) > 0 {
-				require.Error(t, err)
-				assert.Contains(t, err.Error(), tt.expectedErr)
-				return
-			} else {
-				require.NoError(t, err)
-			}
-
-			sch, err := updatedTable.GetSchema(ctx)
-			require.NoError(t, err)
-			originalSch, err := tbl.GetSchema(ctx)
-			require.NoError(t, err)
-			index := originalSch.Indexes().GetByName(dtestutils.IndexName)
-			tt.expectedSchema.Indexes().AddIndex(index)
-			_, err = tt.expectedSchema.Checks().AddCheck("test-check", "age < 123", true)
-			require.NoError(t, err)
-			require.Equal(t, tt.expectedSchema, sch)
-		})
-	}
-}
-
-func TestDropColumnUsedByIndex(t *testing.T) {
-	tests := []struct {
-		name           string
-		colName        string
-		expectedIndex  bool
-		expectedSchema schema.Schema
-	}{
-		{
-			name:           "remove int",
-			colName:        "age",
-			expectedIndex:  true,
-			expectedSchema: dtestutils.RemoveColumnFromSchema(dtestutils.TypedSchema, dtestutils.AgeTag),
-		},
-		{
-			name:           "remove string",
-			colName:        "title",
-			expectedIndex:  true,
-			expectedSchema: dtestutils.RemoveColumnFromSchema(dtestutils.TypedSchema, dtestutils.TitleTag),
-		},
-		{
-			name:           "remove name",
-			colName:        "name",
-			expectedIndex:  false,
-			expectedSchema: dtestutils.RemoveColumnFromSchema(dtestutils.TypedSchema, dtestutils.NameTag),
-		},
-	}
-
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			ctx := context.Background()
-			dEnv, err := makePeopleTable(ctx, dtestutils.CreateTestEnv())
-			require.NoError(t, err)
-
-			root, err := dEnv.WorkingRoot(ctx)
-			require.NoError(t, err)
-			tbl, _, err := root.GetTable(ctx, tableName)
-			require.NoError(t, err)
-
-			updatedTable, err := dropColumn(ctx, tbl, tt.colName)
-			require.NoError(t, err)
-
-			sch, err := updatedTable.GetSchema(ctx)
-			require.NoError(t, err)
-			originalSch, err := tbl.GetSchema(ctx)
-			require.NoError(t, err)
-			_, err = tt.expectedSchema.Checks().AddCheck("test-check", "age < 123", true)
-			require.NoError(t, err)
-
-			index := originalSch.Indexes().GetByName(dtestutils.IndexName)
-			assert.NotNil(t, index)
-			if tt.expectedIndex {
-				tt.expectedSchema.Indexes().AddIndex(index)
-				indexRowData, err := updatedTable.GetIndexRowData(ctx, dtestutils.IndexName)
-				assert.NoError(t, err)
-				assert.NotNil(t, indexRowData)
-			} else {
-				assert.Nil(t, sch.Indexes().GetByName(dtestutils.IndexName))
-				_, err = updatedTable.GetIndexRowData(ctx, dtestutils.IndexName)
-				assert.Error(t, err)
-			}
-			require.Equal(t, tt.expectedSchema, sch)
-		})
-	}
-}
-
 func TestDropPks(t *testing.T) {
 	var dropTests = []struct {
 		name        string
@@ -495,7 +375,7 @@ func TestDropPks(t *testing.T) {
 		{
 			name: "prefer unique key",
 			setup: []string{
-				"create table parent (id int, name varchar(1), age int, primary key (id, age), key `bad_backup` (age, id), key `backup1` (id, age, name), unique key `backup2` (id, age))",
+				"create table parent (id int, name varchar(1), age int, primary key (id, age), key `bad_backup` (age, id), key `backup1` (id, age, name), unique key `backup2` (id, age, name))",
 				"create table child (id int, name varchar(1), age int, constraint `fk` foreign key (id) references parent (id))",
 			},
 			fkIdxName: "backup2",
@@ -561,7 +441,7 @@ func TestDropPks(t *testing.T) {
 			require.NoError(t, err)
 
 			root, _ := dEnv.WorkingRoot(ctx)
-			engine, sqlCtx, err := NewTestEngine(t, dEnv, ctx, db, root)
+			engine, sqlCtx, err := NewTestEngine(dEnv, ctx, db, root)
 			require.NoError(t, err)
 
 			for _, query := range tt.setup {
@@ -589,7 +469,9 @@ func TestDropPks(t *testing.T) {
 				fk, ok := foreignKeyCollection.GetByNameCaseInsensitive(childFkName)
 				assert.True(t, ok)
 				assert.Equal(t, childName, fk.TableName)
-				assert.Equal(t, tt.fkIdxName, fk.ReferencedTableIndex)
+				if tt.fkIdxName != "" && fk.ReferencedTableIndex != "" {
+					assert.Equal(t, tt.fkIdxName, fk.ReferencedTableIndex)
+				}
 
 				parent, ok, err := root.GetTable(ctx, parentName)
 				assert.NoError(t, err)
@@ -890,3 +772,22 @@ func TestModifyColumn(t *testing.T) {
 		})
 	}
 }
+
+// addColToRows adds a column to all the rows given and returns it. This method relies on the fact that
+// noms_row.SetColVal doesn't need a full schema, just one that includes the column being set.
+func addColToRows(t *testing.T, rs []row.Row, tag uint64, val types.Value) []row.Row {
+	if types.IsNull(val) {
+		return rs
+	}
+
+	colColl := schema.NewColCollection(schema.NewColumn("unused", tag, val.Kind(), false))
+	fakeSch := schema.UnkeyedSchemaFromCols(colColl)
+
+	newRows := make([]row.Row, len(rs))
+	var err error
+	for i, r := range rs {
+		newRows[i], err = r.SetColVal(tag, val, fakeSch)
+		require.NoError(t, err)
+	}
+	return newRows
+}
