@@ -38,16 +38,20 @@ type commithook struct {
 	lgr                  atomic.Value // *logrus.Entry
 	remotename           string
 	dbname               string
-	lout                 io.Writer
 	mu                   sync.Mutex
 	wg                   sync.WaitGroup
 	cond                 *sync.Cond
 	nextHead             hash.Hash
 	lastPushedHead       hash.Hash
-	lastPushedSuccess    time.Time
 	nextPushAttempt      time.Time
 	nextHeadIncomingTime time.Time
+	lastSuccess          time.Time
 	currentError         *string
+	cancelReplicate      func()
+
+	// waitNotify is set by controller when it needs to track whether the
+	// commithooks are caught up with replicating to the standby.
+	waitNotify func()
 
 	role Role
 
@@ -136,6 +140,9 @@ func (h *commithook) replicate(ctx context.Context) {
 			h.attemptReplicate(ctx)
 		} else {
 			lgr.Tracef("cluster/commithook: background thread: waiting for signal.")
+			if h.waitNotify != nil {
+				h.waitNotify()
+			}
 			h.cond.Wait()
 			lgr.Tracef("cluster/commithook: background thread: woken up.")
 		}
@@ -144,15 +151,28 @@ func (h *commithook) replicate(ctx context.Context) {
 
 // called with h.mu locked.
 func (h *commithook) shouldReplicate() bool {
-	if h.role != RolePrimary {
-		return false
-	}
-	if h.nextHead == h.lastPushedHead {
+	if h.isCaughtUp() {
 		return false
 	}
 	return (h.nextPushAttempt == (time.Time{}) || time.Now().After(h.nextPushAttempt))
 }
 
+// called with h.mu locked. Returns true if the standby is true-d up, false
+// otherwise. Different from shouldReplicate() in that it does not care about
+// nextPushAttempt, for example. Used in Controller.waitForReplicate.
+func (h *commithook) isCaughtUp() bool {
+	if h.role != RolePrimary {
+		return true
+	}
+	return h.nextHead == h.lastPushedHead
+}
+
+func (h *commithook) isCaughtUpLocking() bool {
+	h.mu.Lock()
+	defer h.mu.Unlock()
+	return h.isCaughtUp()
+}
+
 // called with h.mu locked.
 func (h *commithook) primaryNeedsInit() bool {
 	return h.role == RolePrimary && h.nextHead == (hash.Hash{})
@@ -168,6 +188,13 @@ func (h *commithook) attemptReplicate(ctx context.Context) {
 	toPush := h.nextHead
 	incomingTime := h.nextHeadIncomingTime
 	destDB := h.destDB
+	ctx, h.cancelReplicate = context.WithCancel(ctx)
+	defer func() {
+		if h.cancelReplicate != nil {
+			h.cancelReplicate()
+		}
+		h.cancelReplicate = nil
+	}()
 	h.mu.Unlock()
 
 	if destDB == nil {
@@ -183,6 +210,7 @@ func (h *commithook) attemptReplicate(ctx context.Context) {
 			if toPush == h.nextHead {
 				h.nextPushAttempt = time.Now().Add(1 * time.Second)
 			}
+			h.cancelReplicate = nil
 			return
 		}
 		lgr.Tracef("cluster/commithook: fetched destDB")
@@ -208,20 +236,22 @@ func (h *commithook) attemptReplicate(ctx context.Context) {
 	}
 
 	h.mu.Lock()
-	if err == nil {
-		h.currentError = nil
-		lgr.Tracef("cluster/commithook: successfully Commited chunks on destDB")
-		h.lastPushedHead = toPush
-		h.lastPushedSuccess = incomingTime
-		h.nextPushAttempt = time.Time{}
-	} else {
-		h.currentError = new(string)
-		*h.currentError = fmt.Sprintf("failed to commit chunks on destDB: %v", err)
-		lgr.Warnf("cluster/commithook: failed to commit chunks on destDB: %v", err)
-		// add some delay if a new head didn't come in while we were pushing.
-		if toPush == h.nextHead {
-			// TODO: We could add some backoff here.
-			h.nextPushAttempt = time.Now().Add(1 * time.Second)
+	if h.role == RolePrimary {
+		if err == nil {
+			h.currentError = nil
+			lgr.Tracef("cluster/commithook: successfully Commited chunks on destDB")
+			h.lastPushedHead = toPush
+			h.lastSuccess = incomingTime
+			h.nextPushAttempt = time.Time{}
+		} else {
+			h.currentError = new(string)
+			*h.currentError = fmt.Sprintf("failed to commit chunks on destDB: %v", err)
+			lgr.Warnf("cluster/commithook: failed to commit chunks on destDB: %v", err)
+			// add some delay if a new head didn't come in while we were pushing.
+			if toPush == h.nextHead {
+				// TODO: We could add some backoff here.
+				h.nextPushAttempt = time.Now().Add(1 * time.Second)
+			}
 		}
 	}
 }
@@ -241,20 +271,19 @@ func (h *commithook) status() (replicationLag *time.Duration, lastUpdate *time.T
 				// Operationally, failure to replicate a write for a long time is a
 				// problem that merits investigation, regardless of how many pending
 				// writes are failing to replicate.
-				*replicationLag = time.Now().Sub(h.lastPushedSuccess)
+				*replicationLag = time.Now().Sub(h.lastSuccess)
 			}
 		}
 
-		if h.lastPushedSuccess != (time.Time{}) {
-			lastUpdate := new(time.Time)
-			*lastUpdate = h.lastPushedSuccess
-		}
+	}
+
+	if h.lastSuccess != (time.Time{}) {
+		lastUpdate = new(time.Time)
+		*lastUpdate = h.lastSuccess
 	}
 
 	currentErr = h.currentError
 
-	// TODO: lastUpdate in Standby role.
-
 	return
 }
 
@@ -277,6 +306,16 @@ func (h *commithook) tick(ctx context.Context) {
 	}
 }
 
+func (h *commithook) recordSuccessfulRemoteSrvCommit() {
+	h.mu.Lock()
+	defer h.mu.Unlock()
+	if h.role != RoleStandby {
+		return
+	}
+	h.lastSuccess = time.Now()
+	h.currentError = nil
+}
+
 func (h *commithook) setRole(role Role) {
 	h.mu.Lock()
 	defer h.mu.Unlock()
@@ -285,13 +324,28 @@ func (h *commithook) setRole(role Role) {
 	h.currentError = nil
 	h.nextHead = hash.Hash{}
 	h.lastPushedHead = hash.Hash{}
-	h.lastPushedSuccess = time.Time{}
+	h.lastSuccess = time.Time{}
 	h.nextPushAttempt = time.Time{}
 	h.role = role
 	h.lgr.Store(h.rootLgr.WithField(logFieldRole, string(role)))
+	if h.cancelReplicate != nil {
+		h.cancelReplicate()
+		h.cancelReplicate = nil
+	}
+	if role == RoleDetectedBrokenConfig {
+		h.currentError = &errDetectedBrokenConfigStr
+	}
 	h.cond.Signal()
 }
 
+func (h *commithook) setWaitNotify(f func()) {
+	h.mu.Lock()
+	defer h.mu.Unlock()
+	h.waitNotify = f
+}
+
+var errDetectedBrokenConfigStr = "error: more than one server was configured as primary in the same epoch. this server has stopped accepting writes. choose a primary in the cluster and call dolt_assume_cluster_role() on servers in the cluster to start replication at a higher epoch"
+
 // Execute on this commithook updates the target root hash we're attempting to
 // replicate and wakes the replication thread.
 func (h *commithook) Execute(ctx context.Context, ds datas.Dataset, db datas.Database) error {
@@ -305,6 +359,11 @@ func (h *commithook) Execute(ctx context.Context, ds datas.Dataset, db datas.Dat
 	}
 	h.mu.Lock()
 	defer h.mu.Unlock()
+	lgr = h.logger()
+	if h.role != RolePrimary {
+		lgr.Warnf("cluster/commithook received commit callback for a commit on %s, but we are not role primary; not replicating the commit, which is likely to be lost.", ds.ID())
+		return nil
+	}
 	if root != h.nextHead {
 		lgr.Tracef("signaling replication thread to push new head: %v", root.String())
 		h.nextHeadIncomingTime = time.Now()
@@ -320,7 +379,6 @@ func (h *commithook) HandleError(ctx context.Context, err error) error {
 }
 
 func (h *commithook) SetLogger(ctx context.Context, wr io.Writer) error {
-	h.lout = wr
 	return nil
 }
 
