@@ -592,15 +592,29 @@ func (p DoltDatabaseProvider) DropDatabase(ctx *sql.Context, name string) error
 	dbKey := formatDbMapKeyName(name)
 	db := p.databases[dbKey]
 
+	ddb := db.(Database).ddb
+	err = ddb.Close()
+	if err != nil {
+		return err
+	}
+
 	// get location of database that's being dropped
 	dbLoc := p.dbLocations[dbKey]
 	if dbLoc == nil {
 		return sql.ErrDatabaseNotFound.New(db.Name())
 	}
+
 	dropDbLoc, err := dbLoc.Abs("")
 	if err != nil {
 		return err
 	}
+
+	// If this database is re-created, we don't want to return any cached results.
+	err = dbfactory.DeleteFromSingletonCache("file://" + dropDbLoc + "/.dolt/noms")
+	if err != nil {
+		return err
+	}
+
 	rootDbLoc, err := p.fs.Abs("")
 	if err != nil {
 		return err
