@@ -23,6 +23,7 @@ import (
 	"github.com/dolthub/go-mysql-server/sql/expression"
 
 	"github.com/dolthub/dolt/go/cmd/dolt/cli"
+	"github.com/dolthub/dolt/go/libraries/doltcore/branch_control"
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env/actions"
@@ -72,6 +73,9 @@ func DoDoltMerge(ctx *sql.Context, args []string) (int, int, error) {
 	if len(dbName) == 0 {
 		return noConflictsOrViolations, threeWayMerge, fmt.Errorf("Empty database name.")
 	}
+	if err := branch_control.CheckAccess(ctx, branch_control.Permissions_Write); err != nil {
+		return noConflictsOrViolations, threeWayMerge, err
+	}
 
 	sess := dsess.DSessFromSess(ctx.Session)
 
