@@ -105,6 +105,10 @@ func (dtf *DiffTableFunction) WithExpressions(expression ...sql.Expression) (sql
 		if !expr.Resolved() {
 			return nil, ErrInvalidNonLiteralArgument.New(dtf.Name(), expr.String())
 		}
+		// prepared statements resolve functions beforehand, so above check fails
+		if _, ok := expr.(sql.FunctionExpression); ok {
+			return nil, ErrInvalidNonLiteralArgument.New(dtf.Name(), expr.String())
+		}
 	}
 
 	if strings.Contains(expression[0].String(), "..") {
