@@ -22,7 +22,9 @@ import (
 )
 
 var DoltDocsSqlSchema sql.PrimaryKeySchema
+var OldDoltDocsSqlSchema sql.PrimaryKeySchema
 
 func init() {
 	DoltDocsSqlSchema, _ = sqlutil.FromDoltSchema(doltdb.DocTableName, doltdb.DocsSchema)
+	OldDoltDocsSqlSchema, _ = sqlutil.FromDoltSchema(doltdb.DocTableName, doltdb.OldDocsSchema)
 }
