@@ -46,7 +46,7 @@ var skipPrepared bool
 // SkipPreparedsCount is used by the "ci-check-repo CI workflow
 // as a reminder to consider prepareds when adding a new
 // enginetest suite.
-const SkipPreparedsCount = 85
+const SkipPreparedsCount = 84
 
 const skipPreparedFlag = "DOLT_SKIP_PREPARED_ENGINETESTS"
 
@@ -437,6 +437,10 @@ func TestJoinQueries(t *testing.T) {
 	enginetest.TestJoinQueries(t, newDoltHarness(t))
 }
 
+func TestJoinQueriesPrepared(t *testing.T) {
+	enginetest.TestJoinQueriesPrepared(t, newDoltHarness(t))
+}
+
 // TestJSONTableQueries runs the canonical test queries against a single threaded index enabled harness.
 func TestJSONTableQueries(t *testing.T) {
 	enginetest.TestJSONTableQueries(t, newDoltHarness(t))
@@ -686,8 +690,8 @@ func TestRollbackTriggers(t *testing.T) {
 func TestStoredProcedures(t *testing.T) {
 	tests := make([]queries.ScriptTest, 0, len(queries.ProcedureLogicTests))
 	for _, test := range queries.ProcedureLogicTests {
-		//TODO: fix REPLACE always returning a successful deletion
-		if test.Name != "Parameters resolve inside of REPLACE" {
+		//TODO: this passes locally but SOMETIMES fails tests on GitHub, no clue why
+		if test.Name != "ITERATE and LEAVE loops" {
 			tests = append(tests, test)
 		}
 	}
