@@ -23,19 +23,27 @@ import (
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
-	"github.com/dolthub/dolt/go/libraries/utils/tracing"
 )
 
 // These functions cannot be in the sqlfmt package as the reliance on the sqle package creates a circular reference.
 
-func PrepareCreateTableStmt(ctx context.Context, sqlDb sql.Database) (*sql.Context, *sqle.Engine, *dsess.Session) {
-	sess := dsess.DefaultSession()
-	sqlCtx := sql.NewContext(ctx,
-		sql.WithSession(sess),
-		sql.WithTracer(tracing.Tracer(ctx)))
-
-	pro := NewDoltDatabaseProvider(env.DefaultInitBranch, nil, sqlDb)
+func PrepareCreateTableStmt(ctx context.Context, sqlDb SqlDatabase) (*sql.Context, *sqle.Engine, *dsess.DoltSession) {
+	pro, err := NewDoltDatabaseProviderWithDatabase(env.DefaultInitBranch, nil, sqlDb, nil)
+	if err != nil {
+		return nil, nil, nil
+	}
 	engine := sqle.NewDefault(pro)
+
+	sess := dsess.DefaultSession(pro)
+	sqlCtx := sql.NewContext(ctx, sql.WithSession(sess))
+	dbState, err := GetInitialDBState(ctx, sqlDb)
+	if err != nil {
+		// TODO
+		return nil, nil, nil
+	}
+
+	sess.AddDB(sqlCtx, dbState)
+
 	sqlCtx.SetCurrentDatabase(sqlDb.Name())
 	return sqlCtx, engine, sess
 }
