@@ -26,6 +26,7 @@ import (
 	"context"
 	"errors"
 	"io"
+	"os"
 	"reflect"
 	"sync"
 	"testing"
@@ -61,10 +62,14 @@ func TestRemoteToRemotePulls(t *testing.T) {
 	suite.Run(t, &RemoteToRemoteSuite{})
 }
 
+func TestChunkJournalPulls(t *testing.T) {
+	suite.Run(t, &ChunkJournalSuite{})
+}
+
 type PullSuite struct {
 	suite.Suite
-	sinkCS      *chunks.TestStoreView
-	sourceCS    *chunks.TestStoreView
+	sinkCS      chunks.ChunkStore
+	sourceCS    chunks.ChunkStore
 	sinkVRW     types.ValueReadWriter
 	sourceVRW   types.ValueReadWriter
 	sinkDB      datas.Database
@@ -72,6 +77,13 @@ type PullSuite struct {
 	commitReads int // The number of reads triggered by commit differs across chunk store impls
 }
 
+type metricsChunkStore interface {
+	chunks.ChunkStore
+	Reads() int
+	Hases() int
+	Writes() int
+}
+
 func makeTestStoreViews() (ts1, ts2 *chunks.TestStoreView) {
 	st1, st2 := &chunks.TestStorage{}, &chunks.TestStorage{}
 	return st1.NewView(), st2.NewView()
@@ -128,6 +140,32 @@ func (suite *RemoteToRemoteSuite) SetupTest() {
 	suite.commitReads = 1
 }
 
+type ChunkJournalSuite struct {
+	PullSuite
+}
+
+func (suite *ChunkJournalSuite) SetupTest() {
+	ctx := context.Background()
+	q := nbs.NewUnlimitedMemQuotaProvider()
+	nbf := types.Format_Default.VersionString()
+
+	path, err := os.MkdirTemp("", "remote")
+	suite.NoError(err)
+	sink, err := nbs.NewLocalJournalingStore(ctx, nbf, path, q)
+	suite.NoError(err)
+	path, err = os.MkdirTemp("", "local")
+	suite.NoError(err)
+	src, err := nbs.NewLocalJournalingStore(ctx, nbf, path, q)
+	suite.NoError(err)
+
+	suite.sinkCS, suite.sourceCS = sink, src
+	sinkVRW, sourceVRW := types.NewValueStore(suite.sinkCS), types.NewValueStore(suite.sourceCS)
+	suite.sinkVRW, suite.sourceVRW = sinkVRW, sourceVRW
+	suite.sourceDB = datas.NewTypesDatabase(sourceVRW, tree.NewNodeStore(suite.sourceCS))
+	suite.sinkDB = datas.NewTypesDatabase(sinkVRW, tree.NewNodeStore(suite.sinkCS))
+	suite.commitReads = 1
+}
+
 func (suite *PullSuite) TearDownTest() {
 	suite.sinkCS.Close()
 	suite.sourceCS.Close()
@@ -184,7 +222,11 @@ func (pt *progressTracker) Validate(suite *PullSuite) {
 //
 // Sink: Nada
 func (suite *PullSuite) TestPullEverything() {
-	expectedReads := suite.sinkCS.Reads()
+	var expectedReads int
+	mcs, metrics := suite.sinkCS.(metricsChunkStore)
+	if metrics {
+		expectedReads = mcs.Reads()
+	}
 
 	l := buildListOfHeight(2, suite.sourceVRW)
 	sourceAddr := suite.commitToSource(l, nil)
@@ -194,10 +236,12 @@ func (suite *PullSuite) TestPullEverything() {
 	suite.NoError(err)
 	err = Pull(context.Background(), suite.sourceCS, suite.sinkCS, waf, sourceAddr, pt.Ch)
 	suite.NoError(err)
-	suite.True(expectedReads-suite.sinkCS.Reads() <= suite.commitReads)
+	if metrics {
+		suite.True(expectedReads-suite.sinkCS.(metricsChunkStore).Reads() <= suite.commitReads)
+	}
 	pt.Validate(suite)
 
-	v := mustValue(suite.sinkVRW.ReadValue(context.Background(), sourceAddr)).(types.Struct)
+	v := mustValue(suite.sinkVRW.ReadValue(context.Background(), sourceAddr))
 	suite.NotNil(v)
 	suite.True(l.Equals(mustGetCommittedValue(suite.sinkVRW, v)))
 }
@@ -228,7 +272,11 @@ func (suite *PullSuite) TestPullEverything() {
 func (suite *PullSuite) TestPullMultiGeneration() {
 	sinkL := buildListOfHeight(2, suite.sinkVRW)
 	suite.commitToSink(sinkL, nil)
-	expectedReads := suite.sinkCS.Reads()
+	var expectedReads int
+	mcs, metrics := suite.sinkCS.(metricsChunkStore)
+	if metrics {
+		expectedReads = mcs.Reads()
+	}
 
 	srcL := buildListOfHeight(2, suite.sourceVRW)
 	sourceAddr := suite.commitToSource(srcL, nil)
@@ -244,7 +292,9 @@ func (suite *PullSuite) TestPullMultiGeneration() {
 	err = Pull(context.Background(), suite.sourceCS, suite.sinkCS, waf, sourceAddr, pt.Ch)
 	suite.NoError(err)
 
-	suite.True(expectedReads-suite.sinkCS.Reads() <= suite.commitReads)
+	if metrics {
+		suite.True(expectedReads-suite.sinkCS.(metricsChunkStore).Reads() <= suite.commitReads)
+	}
 	pt.Validate(suite)
 
 	v, err := suite.sinkVRW.ReadValue(context.Background(), sourceAddr)
@@ -292,7 +342,11 @@ func (suite *PullSuite) TestPullDivergentHistory() {
 	srcL, err = srcL.Edit().Set(1, buildListOfHeight(5, suite.sourceVRW)).List(context.Background())
 	suite.NoError(err)
 	sourceAddr = suite.commitToSource(srcL, []hash.Hash{sourceAddr})
-	preReads := suite.sinkCS.Reads()
+	var preReads int
+	mcs, metrics := suite.sinkCS.(metricsChunkStore)
+	if metrics {
+		preReads = mcs.Reads()
+	}
 
 	pt := startProgressTracker()
 
@@ -301,7 +355,9 @@ func (suite *PullSuite) TestPullDivergentHistory() {
 	err = Pull(context.Background(), suite.sourceCS, suite.sinkCS, waf, sourceAddr, pt.Ch)
 	suite.NoError(err)
 
-	suite.True(preReads-suite.sinkCS.Reads() <= suite.commitReads)
+	if metrics {
+		suite.True(preReads-suite.sinkCS.(metricsChunkStore).Reads() <= suite.commitReads)
+	}
 	pt.Validate(suite)
 
 	v, err := suite.sinkVRW.ReadValue(context.Background(), sourceAddr)
@@ -334,7 +390,12 @@ func (suite *PullSuite) TestPullDivergentHistory() {
 func (suite *PullSuite) TestPullUpdates() {
 	sinkL := buildListOfHeight(4, suite.sinkVRW)
 	suite.commitToSink(sinkL, nil)
-	expectedReads := suite.sinkCS.Reads()
+
+	var expectedReads int
+	mcs, metrics := suite.sinkCS.(metricsChunkStore)
+	if metrics {
+		expectedReads = mcs.Reads()
+	}
 
 	srcL := buildListOfHeight(4, suite.sourceVRW)
 	sourceAddr := suite.commitToSource(srcL, nil)
@@ -358,7 +419,9 @@ func (suite *PullSuite) TestPullUpdates() {
 	err = Pull(context.Background(), suite.sourceCS, suite.sinkCS, waf, sourceAddr, pt.Ch)
 	suite.NoError(err)
 
-	suite.True(expectedReads-suite.sinkCS.Reads() <= suite.commitReads)
+	if metrics {
+		suite.True(expectedReads-suite.sinkCS.(metricsChunkStore).Reads() <= suite.commitReads)
+	}
 	pt.Validate(suite)
 
 	v, err := suite.sinkVRW.ReadValue(context.Background(), sourceAddr)
