@@ -63,6 +63,8 @@ type awsTablePersister struct {
 	q      MemoryQuotaProvider
 }
 
+var _ tablePersister = awsTablePersister{}
+
 type awsLimits struct {
 	partTarget, partMin, partMax uint64
 	itemMax                      int
@@ -512,8 +514,7 @@ func dividePlan(ctx context.Context, plan compactionPlan, minPartSize, maxPartSi
 	var offset int64
 	for ; i < len(plan.sources.sws); i++ {
 		sws := plan.sources.sws[i]
-		rdr, err := sws.source.reader(ctx)
-
+		rdr, _, err := sws.source.reader(ctx)
 		if err != nil {
 			return nil, nil, nil, err
 		}
