@@ -25,7 +25,6 @@ import (
 	"bytes"
 	"context"
 	"crypto/rand"
-	"errors"
 	"os"
 	"path/filepath"
 	"sort"
@@ -437,14 +436,14 @@ func (suite *BlockStoreSuite) TestChunkStorePutWithRebase() {
 }
 
 func TestBlockStoreConjoinOnCommit(t *testing.T) {
-	stats := &Stats{}
 	assertContainAll := func(t *testing.T, store chunks.ChunkStore, sources ...chunkSource) {
 		ctx := context.Background()
 		for _, src := range sources {
 			err := extractAllChunks(ctx, src, func(rec extractRecord) {
 				ok, err := store.Has(context.Background(), hash.Hash(rec.a))
 				require.NoError(t, err)
-				assert.True(t, ok)
+				assert.True(t, ok, "chunk %s from chunkSource %s not found in store",
+					rec.a.String(), src.hash().String())
 			})
 			require.NoError(t, err)
 		}
@@ -483,19 +482,6 @@ func TestBlockStoreConjoinOnCommit(t *testing.T) {
 		assert.True(t, ok)
 	})
 
-	makeCanned := func(conjoinees, keepers []tableSpec, p tablePersister) cannedConjoin {
-		srcs := chunkSources{}
-		for _, sp := range conjoinees {
-			cs, err := p.Open(context.Background(), sp.name, sp.chunkCount, nil)
-			require.NoError(t, err)
-			srcs = append(srcs, cs)
-		}
-		conjoined, err := p.ConjoinAll(context.Background(), srcs, stats)
-		require.NoError(t, err)
-		cannedSpecs := []tableSpec{{conjoined.hash(), mustUint32(conjoined.count())}}
-		return cannedConjoin{true, append(cannedSpecs, keepers...)}
-	}
-
 	t.Run("ConjoinSuccess", func(t *testing.T) {
 		fm := &fakeManifest{}
 		q := NewUnlimitedMemQuotaProvider()
@@ -506,7 +492,9 @@ func TestBlockStoreConjoinOnCommit(t *testing.T) {
 		require.NoError(t, err)
 		fm.set(constants.NomsVersion, computeAddr([]byte{0xbe}), hash.Of([]byte{0xef}), upstream, nil)
 		c := &fakeConjoiner{
-			[]cannedConjoin{makeCanned(upstream[:2], upstream[2:], p)},
+			[]cannedConjoin{
+				{conjoinees: upstream[:2], keepers: upstream[2:]},
+			},
 		}
 
 		smallTableStore, err := newNomsBlockStore(context.Background(), constants.FormatDefaultString, makeManifestManager(fm), p, q, c, testMemTableSize)
@@ -541,8 +529,8 @@ func TestBlockStoreConjoinOnCommit(t *testing.T) {
 		fm.set(constants.NomsVersion, computeAddr([]byte{0xbe}), hash.Of([]byte{0xef}), upstream, nil)
 		c := &fakeConjoiner{
 			[]cannedConjoin{
-				makeCanned(upstream[:2], upstream[2:], p),
-				makeCanned(upstream[:4], upstream[4:], p),
+				{conjoinees: upstream[:2], keepers: upstream[2:]},
+				{conjoinees: upstream[:4], keepers: upstream[4:]},
 			},
 		}
 
@@ -569,45 +557,27 @@ func TestBlockStoreConjoinOnCommit(t *testing.T) {
 }
 
 type cannedConjoin struct {
-	should bool
-	specs  []tableSpec // Must name tables that are already persisted
+	// Must name tables that are already persisted
+	conjoinees, keepers []tableSpec
 }
 
 type fakeConjoiner struct {
 	canned []cannedConjoin
 }
 
-func (fc *fakeConjoiner) ConjoinRequired(ts tableSet) bool {
+func (fc *fakeConjoiner) conjoinRequired(ts tableSet) bool {
 	if len(fc.canned) == 0 {
 		return false
 	}
-	return fc.canned[0].should
+	return true
 }
 
-func (fc *fakeConjoiner) Conjoin(ctx context.Context, upstream manifestContents, mm manifestUpdater, p tablePersister, stats *Stats) (manifestContents, error) {
+func (fc *fakeConjoiner) chooseConjoinees(specs []tableSpec) (conjoinees, keepers []tableSpec, err error) {
 	d.PanicIfTrue(len(fc.canned) == 0)
-	canned := fc.canned[0]
+	cur := fc.canned[0]
 	fc.canned = fc.canned[1:]
-
-	newContents := manifestContents{
-		nbfVers: constants.NomsVersion,
-		root:    upstream.root,
-		specs:   canned.specs,
-		lock:    generateLockHash(upstream.root, canned.specs, []tableSpec{}),
-	}
-
-	var err error
-	upstream, err = mm.Update(context.Background(), upstream.lock, newContents, stats, nil)
-
-	if err != nil {
-		return manifestContents{}, err
-	}
-
-	if upstream.lock != newContents.lock {
-		return manifestContents{}, errors.New("lock failed")
-	}
-
-	return upstream, err
+	conjoinees, keepers = cur.conjoinees, cur.keepers
+	return
 }
 
 func assertInputInStore(input []byte, h hash.Hash, s chunks.ChunkStore, assert *assert.Assertions) {
