@@ -23,7 +23,6 @@ import (
 	"io"
 	"os"
 	"path/filepath"
-	"sync"
 
 	"github.com/dolthub/dolt/go/store/d"
 	"github.com/dolthub/dolt/go/store/hash"
@@ -40,56 +39,84 @@ const (
 )
 
 var (
-	openJournals = new(sync.Map)
-	journalAddr  = addr(hash.Parse(chunkJournalAddr))
+	journalAddr = addr(hash.Parse(chunkJournalAddr))
 )
 
-func openJournalWriter(ctx context.Context, path string) (wr *journalWriter, err error) {
-	var f *os.File
+func isJournalAddr(a addr) bool {
+	return a == journalAddr
+}
 
+func journalFileExists(path string) (bool, error) {
+	var err error
+	if path, err = filepath.Abs(path); err != nil {
+		return false, err
+	}
+
+	info, err := os.Stat(path)
+	if errors.Is(err, os.ErrNotExist) {
+		return false, nil
+	} else if info.IsDir() {
+		return true, fmt.Errorf("expected file %s found directory", chunkJournalName)
+	}
+	return true, nil
+}
+
+func openJournalWriter(ctx context.Context, path string) (wr *journalWriter, exists bool, err error) {
+	var f *os.File
+	if path, err = filepath.Abs(path); err != nil {
+		return nil, false, err
+	}
+
+	info, err := os.Stat(path)
+	if errors.Is(err, os.ErrNotExist) {
+		return nil, false, nil
+	} else if err != nil {
+		return nil, false, err
+	} else if info.IsDir() {
+		return nil, true, fmt.Errorf("expected file %s found directory", chunkJournalName)
+	}
+	if f, err = os.OpenFile(path, os.O_RDWR, 0666); err != nil {
+		return nil, true, err
+	}
+
+	return &journalWriter{
+		buf:  make([]byte, 0, journalWriterBuffSize),
+		file: f,
+		path: path,
+	}, true, nil
+}
+
+func createJournalWriter(ctx context.Context, path string) (wr *journalWriter, err error) {
+	var f *os.File
 	if path, err = filepath.Abs(path); err != nil {
 		return nil, err
 	}
 
-	if _, ok := openJournals.Load(path); ok {
-		return nil, fmt.Errorf("journal (%s) already opened in-process", path)
-	}
-	openJournals.Store(path, true)
-
-	var create bool
-	info, err := os.Stat(path)
-	if errors.Is(err, os.ErrNotExist) {
-		create = true
-	} else if err != nil {
+	_, err = os.Stat(path)
+	if err == nil {
+		return nil, fmt.Errorf("journal file %s already exists", chunkJournalName)
+	} else if !errors.Is(err, os.ErrNotExist) {
 		return nil, err
-	} else if info.IsDir() {
-		return nil, fmt.Errorf("expected file %s found directory", chunkJournalName)
 	}
 
-	if create {
-		if f, err = os.OpenFile(path, os.O_RDWR|os.O_CREATE, 0666); err != nil {
-			return nil, err
-		}
-		const batch = 1024 * 1024
-		b := make([]byte, batch)
-		for i := 0; i < chunkJournalFileSize; i += batch {
-			if _, err = f.Write(b); err != nil { // zero fill |f|
-				return nil, err
-			}
-		}
-		if err = f.Sync(); err != nil {
-			return nil, err
-		}
-		if o, err := f.Seek(0, io.SeekStart); err != nil {
-			return nil, err
-		} else if o != 0 {
-			return nil, fmt.Errorf("expected file offset 0, got %d", o)
-		}
-	} else {
-		if f, err = os.OpenFile(path, os.O_RDWR, 0666); err != nil {
+	if f, err = os.OpenFile(path, os.O_RDWR|os.O_CREATE, 0666); err != nil {
+		return nil, err
+	}
+	const batch = 1024 * 1024
+	b := make([]byte, batch)
+	for i := 0; i < chunkJournalFileSize; i += batch {
+		if _, err = f.Write(b); err != nil { // zero fill |f|
 			return nil, err
 		}
 	}
+	if err = f.Sync(); err != nil {
+		return nil, err
+	}
+	if o, err := f.Seek(0, io.SeekStart); err != nil {
+		return nil, err
+	} else if o != 0 {
+		return nil, fmt.Errorf("expected file offset 0, got %d", o)
+	}
 
 	return &journalWriter{
 		buf:  make([]byte, 0, journalWriterBuffSize),
@@ -98,6 +125,16 @@ func openJournalWriter(ctx context.Context, path string) (wr *journalWriter, err
 	}, nil
 }
 
+type snapshotReader interface {
+	io.ReaderAt
+	// Snapshot returns an io.Reader that provides a consistent view
+	// of the current state of the snapshotReader.
+	snapshot() (io.Reader, int64, error)
+
+	// currentSize returns the current size.
+	currentSize() int64
+}
+
 type journalWriter struct {
 	buf  []byte
 	file *os.File
@@ -105,8 +142,8 @@ type journalWriter struct {
 	path string
 }
 
-var _ io.ReaderAt = &journalWriter{}
 var _ io.WriteCloser = &journalWriter{}
+var _ snapshotReader = &journalWriter{}
 
 func (wr *journalWriter) filepath() string {
 	return wr.path
@@ -135,6 +172,23 @@ func (wr *journalWriter) ReadAt(p []byte, off int64) (n int, err error) {
 	return
 }
 
+func (wr *journalWriter) snapshot() (io.Reader, int64, error) {
+	if err := wr.flush(); err != nil {
+		return nil, 0, err
+	}
+	// open a new file descriptor with an
+	// independent lifecycle from |wr.file|
+	f, err := os.Open(wr.path)
+	if err != nil {
+		return nil, 0, err
+	}
+	return io.LimitReader(f, wr.off), wr.off, nil
+}
+
+func (wr *journalWriter) currentSize() int64 {
+	return wr.off
+}
+
 func (wr *journalWriter) Write(p []byte) (n int, err error) {
 	if len(p) > len(wr.buf) {
 		// write directly to |wr.file|
@@ -153,8 +207,8 @@ func (wr *journalWriter) Write(p []byte) (n int, err error) {
 	return
 }
 
-func (wr *journalWriter) bootstrapJournal(ctx context.Context) (last hash.Hash, cs journalChunkSource, err error) {
-	// bootstrap chunk journal from |wr.file|
+func (wr *journalWriter) processJournal(ctx context.Context) (last hash.Hash, cs journalChunkSource, err error) {
+	// maybeInitJournal chunk journal from |wr.file|
 	src := journalChunkSource{
 		journal: wr,
 		address: journalAddr,
@@ -245,21 +299,9 @@ func (wr *journalWriter) Close() (err error) {
 	if cerr := wr.file.Close(); cerr != nil {
 		err = cerr
 	}
-	openJournals.Delete(wr.path)
 	return
 }
 
-// todo(andy): extensible record format
-type jrecord struct {
-	length   uint32
-	kind     jrecordKind
-	address  addr
-	payload  []byte
-	checksum uint32
-}
-
-type jrecordKind uint8
-
 const (
 	unknownKind  jrecordKind = 0
 	rootHashKind jrecordKind = 1
@@ -270,9 +312,34 @@ const (
 	recMinSz  = recLenSz + recKindSz + addrSize + checksumSize
 	recMaxSz  = 128 * 1024 // todo(andy): less arbitrary
 
-	rootHashRecordSize = recMinSz
+	chunkRecordHeaderSize = recLenSz + recKindSz + addrSize
+	rootHashRecordSize    = recMinSz
 )
 
+type jrecordKind uint8
+
+// todo(andy): extensible record format
+type jrecord struct {
+	length   uint32
+	kind     jrecordKind
+	address  addr
+	payload  []byte
+	checksum uint32
+}
+
+type jrecordLookup struct {
+	offset int64
+	length uint32
+}
+
+func rangeFromLookup(l jrecordLookup) Range {
+	return Range{
+		Offset: uint64(l.offset) + chunkRecordHeaderSize,
+		// jrecords are currently double check-summed
+		Length: uint32(l.length) - (chunkRecordHeaderSize + checksumSize),
+	}
+}
+
 func chunkRecordSize(c CompressedChunk) uint32 {
 	return uint32(len(c.FullCompressedChunk)) + recMinSz
 }
