@@ -27,7 +27,6 @@ import (
 	"io"
 	"os"
 	"path/filepath"
-	"reflect"
 	"sort"
 	"sync"
 	"sync/atomic"
@@ -93,7 +92,7 @@ type NBSCompressedChunkStore interface {
 type NomsBlockStore struct {
 	mm manifestManager
 	p  tablePersister
-	c  conjoiner
+	c  conjoinStrategy
 
 	mu       sync.RWMutex // protects the following state
 	mt       *memTable
@@ -128,74 +127,24 @@ func (nbs *NomsBlockStore) GetChunkLocationsWithPaths(hashes hash.HashSet) (map[
 
 func (nbs *NomsBlockStore) GetChunkLocations(hashes hash.HashSet) (map[hash.Hash]map[hash.Hash]Range, error) {
 	gr := toGetRecords(hashes)
-
-	forIndex := func(ti tableIndex, cur map[hash.Hash]Range) (map[hash.Hash]Range, error) {
-		if cur == nil {
-			cur = make(map[hash.Hash]Range)
-		}
-		var foundHashes []hash.Hash
-		for h := range hashes {
-			a := addr(h)
-			e, ok, err := ti.lookup(&a)
-			if err != nil {
-				return nil, err
-			}
-			if ok {
-				foundHashes = append(foundHashes, h)
-				cur[h] = Range{Offset: e.Offset(), Length: e.Length()}
-			}
-		}
-		for _, h := range foundHashes {
-			delete(hashes, h)
-		}
-		return cur, nil
-	}
-
 	ranges := make(map[hash.Hash]map[hash.Hash]Range)
-	f := func(css chunkSourceSet) error {
+
+	fn := func(css chunkSourceSet) error {
 		for _, cs := range css {
-			switch tr := cs.(type) {
-			case *fileTableReader:
-				offsetRecSlice, _, err := tr.findOffsets(gr)
-				if err != nil {
-					return err
-				}
-				if len(offsetRecSlice) > 0 {
-					y, ok := ranges[hash.Hash(tr.h)]
-
-					if !ok {
-						y = make(map[hash.Hash]Range)
-					}
-
-					for _, offsetRec := range offsetRecSlice {
-						h := hash.Hash(*offsetRec.a)
-						y[h] = Range{Offset: offsetRec.offset, Length: offsetRec.length}
-
-						delete(hashes, h)
-					}
-
-					if len(offsetRecSlice) > 0 {
-						gr = toGetRecords(hashes)
-					}
-
-					ranges[hash.Hash(tr.h)] = y
-				}
-			case *chunkSourceAdapter:
-				tableIndex, err := tr.index()
-				if err != nil {
-					return err
-				}
-				found, err := forIndex(tableIndex, ranges[hash.Hash(tr.h)])
-				if err != nil {
-					return err
-				}
-				ranges[hash.Hash(tr.h)] = found
-			default:
-				panic(reflect.TypeOf(cs))
+			rng, err := cs.getRecordRanges(gr)
+			if err != nil {
+				return err
 			}
 
+			h := hash.Hash(cs.hash())
+			if m, ok := ranges[h]; ok {
+				for k, v := range rng {
+					m[k] = v
+				}
+			} else {
+				ranges[h] = rng
+			}
 		}
-
 		return nil
 	}
 
@@ -205,18 +154,12 @@ func (nbs *NomsBlockStore) GetChunkLocations(hashes hash.HashSet) (map[hash.Hash
 		return nbs.tables
 	}()
 
-	err := f(tables.upstream)
-
-	if err != nil {
+	if err := fn(tables.upstream); err != nil {
 		return nil, err
 	}
-
-	err = f(tables.novel)
-
-	if err != nil {
+	if err := fn(tables.novel); err != nil {
 		return nil, err
 	}
-
 	return ranges, nil
 }
 
@@ -533,21 +476,33 @@ func newLocalStore(ctx context.Context, nbfVerStr string, dir string, memTableSi
 		return nil, err
 	}
 	p := newFSTablePersister(dir, globalFDCache, q)
+	c := conjoinStrategy(inlineConjoiner{maxTables})
 
-	if chunkJournalFeatureFlag {
-		j, err := newChunkJournal(ctx, dir, m)
-		if err != nil {
-			return nil, err
-		}
-		m, p = j, j
+	return newNomsBlockStore(ctx, nbfVerStr, makeManifestManager(m), p, q, c, memTableSize)
+}
+
+func NewLocalJournalingStore(ctx context.Context, nbfVers, dir string, q MemoryQuotaProvider) (*NomsBlockStore, error) {
+	cacheOnce.Do(makeGlobalCaches)
+	if err := checkDir(dir); err != nil {
+		return nil, err
 	}
-	mm := makeManifestManager(m)
 
-	nbs, err := newNomsBlockStore(ctx, nbfVerStr, mm, p, q, inlineConjoiner{maxTables}, memTableSize)
+	m, err := getFileManifest(ctx, dir)
 	if err != nil {
 		return nil, err
 	}
-	return nbs, nil
+	p := newFSTablePersister(dir, globalFDCache, q)
+
+	journal, err := newChunkJournal(ctx, nbfVers, dir, m, p.(*fsTablePersister))
+	if err != nil {
+		return nil, err
+	}
+
+	mm := makeManifestManager(journal)
+	c := journalConjoiner{child: inlineConjoiner{defaultMaxTables}}
+
+	// |journal| serves as the manifest and tablePersister
+	return newNomsBlockStore(ctx, nbfVers, mm, journal, q, c, defaultMemTableSize)
 }
 
 func checkDir(dir string) error {
@@ -561,7 +516,7 @@ func checkDir(dir string) error {
 	return nil
 }
 
-func newNomsBlockStore(ctx context.Context, nbfVerStr string, mm manifestManager, p tablePersister, q MemoryQuotaProvider, c conjoiner, memTableSize uint64) (*NomsBlockStore, error) {
+func newNomsBlockStore(ctx context.Context, nbfVerStr string, mm manifestManager, p tablePersister, q MemoryQuotaProvider, c conjoinStrategy, memTableSize uint64) (*NomsBlockStore, error) {
 	if memTableSize == 0 {
 		memTableSize = defaultMemTableSize
 	}
@@ -1081,17 +1036,13 @@ func (nbs *NomsBlockStore) updateManifest(ctx context.Context, current, last has
 		}
 	}
 
-	if nbs.c.ConjoinRequired(nbs.tables) {
-		var err error
-
-		newUpstream, err := nbs.c.Conjoin(ctx, nbs.upstream, nbs.mm, nbs.p, nbs.stats)
-
+	if nbs.c.conjoinRequired(nbs.tables) {
+		newUpstream, err := conjoin(ctx, nbs.c, nbs.upstream, nbs.mm, nbs.p, nbs.stats)
 		if err != nil {
 			return err
 		}
 
 		newTables, err := nbs.tables.rebase(ctx, newUpstream.specs, nbs.stats)
-
 		if err != nil {
 			return err
 		}
@@ -1103,7 +1054,6 @@ func (nbs *NomsBlockStore) updateManifest(ctx context.Context, current, last has
 		if err != nil {
 			return err
 		}
-
 		return errOptimisticLockFailedTables
 	}
 
@@ -1173,6 +1123,9 @@ func (nbs *NomsBlockStore) Close() (err error) {
 	if cerr := nbs.tables.close(); cerr != nil {
 		err = cerr
 	}
+	if cerr := nbs.mm.Close(); cerr != nil {
+		err = cerr
+	}
 	return
 }
 
@@ -1267,15 +1220,10 @@ func newTableFile(cs chunkSource, info tableSpec) tableFile {
 	return tableFile{
 		info: info,
 		open: func(ctx context.Context) (io.ReadCloser, uint64, error) {
-			s, err := cs.size()
+			r, s, err := cs.reader(ctx)
 			if err != nil {
 				return nil, 0, err
 			}
-			r, err := cs.reader(ctx)
-			if err != nil {
-				return nil, 0, err
-			}
-
 			return io.NopCloser(r), s, nil
 		},
 	}
@@ -1309,11 +1257,7 @@ func (nbs *NomsBlockStore) Size(ctx context.Context) (uint64, error) {
 		if !ok {
 			return uint64(0), errors.New("manifest referenced table file for which there is no chunkSource.")
 		}
-		sz, err := cs.size()
-		if err != nil {
-			return uint64(0), fmt.Errorf("error getting table file index for chunkSource. %w", err)
-		}
-		size += sz
+		size += cs.currentSize()
 	}
 	return size, nil
 }
@@ -1331,7 +1275,11 @@ func (nbs *NomsBlockStore) chunkSourcesByAddr() (map[addr]chunkSource, error) {
 }
 
 func (nbs *NomsBlockStore) SupportedOperations() TableFileStoreOps {
-	_, ok := nbs.p.(*fsTablePersister)
+	var ok bool
+	switch nbs.p.(type) {
+	case *fsTablePersister, *chunkJournal:
+		ok = true
+	}
 	return TableFileStoreOps{
 		CanRead:  true,
 		CanWrite: ok,
@@ -1341,17 +1289,21 @@ func (nbs *NomsBlockStore) SupportedOperations() TableFileStoreOps {
 }
 
 func (nbs *NomsBlockStore) Path() (string, bool) {
-	fsPersister, ok := nbs.p.(*fsTablePersister)
-	if !ok {
-		return "", false
+	if tfp, ok := nbs.p.(tableFilePersister); ok {
+		return tfp.Path(), true
 	}
-	return fsPersister.dir, true
+	return "", false
 }
 
 // WriteTableFile will read a table file from the provided reader and write it to the TableFileStore
 func (nbs *NomsBlockStore) WriteTableFile(ctx context.Context, fileId string, numChunks int, contentHash []byte, getRd func() (io.ReadCloser, uint64, error)) error {
-	fsPersister, ok := nbs.p.(*fsTablePersister)
-	if !ok {
+	var fsPersister *fsTablePersister
+	switch t := nbs.p.(type) {
+	case *fsTablePersister:
+		fsPersister = t
+	case *chunkJournal:
+		fsPersister = t.persister
+	default:
 		return errors.New("Not implemented")
 	}
 
@@ -1540,6 +1492,12 @@ func (nbs *NomsBlockStore) copyMarkedChunks(ctx context.Context, keepChunks <-ch
 		return nil, err
 	}
 
+	tfp, ok := dest.p.(tableFilePersister)
+	if !ok {
+		return nil, fmt.Errorf("NBS does not support copying garbage collection")
+	}
+	path := tfp.Path()
+
 LOOP:
 	for {
 		select {
@@ -1568,13 +1526,10 @@ LOOP:
 			return nil, ctx.Err()
 		}
 	}
-
-	nomsDir := dest.p.(*fsTablePersister).dir
-
-	return gcc.copyTablesToDir(ctx, nomsDir)
+	return gcc.copyTablesToDir(ctx, path)
 }
 
-// todo: what's the optimal table size to copy to?
+// todo: what's the optimal table currentSize to copy to?
 func (nbs *NomsBlockStore) gcTableSize() (uint64, error) {
 	total, err := nbs.tables.physicalLen()
 
