@@ -142,6 +142,13 @@ func (b *binaryNomsReader) readUint16() uint16 {
 	return v
 }
 
+func (b *binaryNomsReader) readUint24() uint32 {
+	var bs [4]byte
+	copy(bs[1:], b.buff[b.offset:])
+	b.offset += 3
+	return binary.BigEndian.Uint32(bs[:])
+}
+
 func (b *binaryNomsReader) PeekKind() NomsKind {
 	return NomsKind(b.peekUint8())
 }
@@ -325,10 +332,10 @@ func (b *binaryNomsReader) ReadInlineBlob() []byte {
 	return bytes
 }
 
-func (b *binaryNomsReader) readTupleRowStorage() []byte {
-	size := uint32(b.readUint16())
-	// start at offset-3, to include the kind byte + Uint16 for size...
-	bytes := b.buff[b.offset-3 : b.offset+size]
+func (b *binaryNomsReader) readSerialMessage() []byte {
+	size := b.readUint24()
+	// start at offset-4, to include the kind byte + Uint24 for size...
+	bytes := b.buff[b.offset-4 : b.offset+size]
 	b.offset += size
 	return bytes
 }
